DADissenter

Struct DADissenter 

pub struct DADissenter { /* private fields */ }
Available on crate feature DADissenter only.
Type of a reference to DADissenter instances.

See also Apple’s documentation

Implementations

Source

impl DADissenter

pub unsafe fn new( allocator: Option<&CFAllocator>, status: DAReturn, string: Option<&CFString>, ) -> CFRetained<DADissenter>

Available on crate feature libc only.

Creates a new dissenter object.

Parameter allocator: The allocator object to be used to allocate memory.

Parameter status: The return code.

Parameter string: The return code string. Pass NULL for no reason.

Returns: A reference to a new DADissenter.

pub unsafe fn status(&self) -> DAReturn

Available on crate feature libc only.

Obtains the return code.

Parameter dissenter: The DADissenter for which to obtain the return code.

Returns: The return code. A BSD return code, if applicable, is encoded with unix_err().

pub unsafe fn status_string(&self) -> Option<CFRetained<CFString>>

Obtains the return code string.

Parameter dissenter: The DADissenter for which to obtain the return code string.

Returns: The return code string.

Methods from Deref<Target = CFType>

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: ConcreteType,

Attempt to downcast the type to that of type T.

This is the reference-variant. Use CFRetained::downcast if you want to convert a retained type. See also ConcreteType for more details on which types support being converted to.

pub fn retain_count(&self) -> usize

Get the reference count of the object.

This function may be useful for debugging. You normally do not use this function otherwise.

Beware that some things (like CFNumbers, small CFStrings etc.) may not have a normal retain count for optimization purposes, and can return usize::MAX in that case.